@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.08';
+$Footprintless::Overlay::VERSION = '1.09';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -60,6 +60,18 @@ sub _dirs_template {
     &$with_dirs_work( $base_dir, $template_dir, $to_dir );
 }
 
+sub _dot_footprintless_resolver {
+    my ($self) = @_;
+    return sub {
+        my ( $template, $destination ) = @_;
+        if ( $template =~ /\/\.footprintless$/ ) {
+            $self->_resolve_footprintless( $template, $destination );
+            return 1;
+        }
+        return 0;
+    };
+}
+
 sub _init {
     my ( $self, $factory, $coordinate, %options ) = @_;
     $logger->tracef( "coordinate=[%s],options=[%s]", $coordinate, \%options );
@@ -96,15 +108,8 @@ sub _initialize {
     my ( $self, $base_dir, $template_dir, $to_dir ) = @_;
     $self->_overlay($base_dir)->overlay(
         $template_dir,
-        to       => $to_dir,
-        resolver => sub {
-            my ( $template, $destination ) = @_;
-            if ( $template =~ /\/\.footprintless$/ ) {
-                $self->_resolve_footprintless( $template, $destination );
-                return 1;
-            }
-            return 0;
-        }
+        resolver => $self->_dot_footprintless_resolver(),
+        to       => $to_dir
     );
 }
 
@@ -192,7 +197,8 @@ sub update {
 sub _update {
     my ( $self, $base_dir, $template_dir, $to_dir ) = @_;
     $logger->tracef( "update to=[%s], template=[%s]", $to_dir, $template_dir );
-    $self->_overlay($to_dir)->overlay($template_dir);
+    $self->_overlay($to_dir)
+        ->overlay( $template_dir, resolver => $self->_dot_footprintless_resolver() );
 }
 
 1;
@@ -207,7 +213,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
