@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.08';
+$Footprintless::Util::VERSION = '1.09';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -219,7 +219,7 @@ sub spurt {
 sub temp_dir {
     require File::Temp;
     File::Temp->safe_level( File::Temp::HIGH() );
-    my $temp = File::Temp->newdir();
+    my $temp = File::Temp->newdir( 'fpl_XXXXXXXX', TMPDIR => 1 );
     if ( !chmod( 0700, $temp ) ) {
         croak("unable to create secure temp file");
     }
@@ -229,7 +229,7 @@ sub temp_dir {
 sub temp_file {
     require File::Temp;
     File::Temp->safe_level( File::Temp::HIGH() );
-    my $temp = File::Temp->new();
+    my $temp = File::Temp->new( 'fpl_XXXXXXXX', TMPDIR => 1 );
     if ( !chmod( 0600, $temp ) ) {
         croak("unable to create secure temp file");
     }
@@ -248,7 +248,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
